@@ -6,9 +6,9 @@ import logging
 
 from RubyFormatter.fileFormatter import FileFormatter
 from RubyFormatter.cmdParser import CmdParser
-import RubyFormatter.log
+# import RubyFormatter.log
 
-__version__ = "0.2.0"
+__version__ = "0.2.1"
 
 logger = logging.getLogger('Formatter')
 
